=============
datagrid_gtk3
=============

.. image:: https://semaphoreci.com/api/v1/projects/bd20f827-7591-4c58-87bb-e9235fdb9a0a/422070/shields_badge.svg
    :target: https://semaphoreci.com/nowsecure/datagrid-gtk3
    :alt: Test Results

.. image:: https://coveralls.io/repos/nowsecure/datagrid-gtk3/badge.svg
    :target: https://coveralls.io/r/nowsecure/datagrid-gtk3
    :alt: Test Coverage

.. image:: https://landscape.io/github/nowsecure/datagrid-gtk3/master/landscape.svg?style=flat
    :target: https://landscape.io/github/nowsecure/datagrid-gtk3/master
    :alt: Code Health


SYNOPSIS
========

MVC framework for working with the Gtk3 TreeView widget.
Includes classes for file browsing and displaying SQLite databases.


MOTIVATION
==========

Created on the account of the reoccurring need to display and interact with
contents of SQLite databases in Gtk applications.
